# 015

|                                                           | 015-000         | 015-dishwasher-60.2   |
|:----------------------------------------------------------|:----------------|:----------------------|
| bindTime                                                  | 1668542674215   | 1668542674215         |
| createTime                                                | 0               | 0                     |
| deviceFeatureCode                                         | 000             | dishwasher-60.2       |
| deviceFeatureName                                         | W-DW50/60-22    | W-DW50/60-22          |
| deviceId                                                  | <redacted>      | <redacted>            |
| deviceNickName                                            | ASKO dishwasher | Oppvaskmaskin         |
| deviceTypeCode                                            | 015             | 015                   |
| deviceTypeName                                            |                 |                       |
| isShow                                                    |                 | 1                     |
| offlineState                                              | 1               | 1                     |
| puid                                                      | <redacted>      | <redacted>            |
| role                                                      | 1               | 1                     |
| roomId                                                    | 1044366         | 1044366               |
| roomName                                                  | Kjøkken         | Kjøkken               |
| seq                                                       | 0               | 0                     |
| statusList.ADO_allowed                                    | 1               |                       |
| statusList.Alarm_Autodose_level10                         | 0               |                       |
| statusList.Alarm_Autodose_level20                         | 0               |                       |
| statusList.Alarm_External_autodose_level15                | 0               |                       |
| statusList.Alarm_External_autodose_level30                | 0               |                       |
| statusList.Alarm_Rinse_aid_refill_external                | 0               |                       |
| statusList.Alarm_Sani_program_finished                    | 0               |                       |
| statusList.Alarm_auto_dose_refill                         | 0               | 0                     |
| statusList.Alarm_clean_the_filters                        | 1               | 1                     |
| statusList.Alarm_door_closed                              | 1               | 1                     |
| statusList.Alarm_door_opened                              | 1               | 1                     |
| statusList.Alarm_preheating_ready                         | 0               | 0                     |
| statusList.Alarm_program_done                             | 1               | 1                     |
| statusList.Alarm_program_pause                            | 1               | 1                     |
| statusList.Alarm_remote_start_canceled                    | 1               | 1                     |
| statusList.Alarm_rinse_aid_refill                         | 1               | 1                     |
| statusList.Alarm_run_selfcleaning                         | 1               | 1                     |
| statusList.Alarm_salt_refill                              | 1               | 1                     |
| statusList.Auto_dose_duration                             | 244             |                       |
| statusList.Auto_dose_quantity_setting_status              | 3               | 1                     |
| statusList.Auto_dose_refill                               | 1               | 1                     |
| statusList.Auto_dose_setting_status                       | 2               | 1                     |
| statusList.Child_lock                                     | 1               | 1                     |
| statusList.Child_lock_setting_status                      | 1               | 1                     |
| statusList.Curent_program_duration                        | 131             | 132                   |
| statusList.Curent_program_remaining_time                  | 86              | 65535                 |
| statusList.Current_program_phase                          | 7               | 1                     |
| statusList.Current_temperature                            | 0               |                       |
| statusList.Delay_start                                    | 1               | 1                     |
| statusList.Delay_start_remaining_time                     | 0               | 0                     |
| statusList.Delay_start_set_time                           | 0               | 0                     |
| statusList.Demo_mode_status                               | 0               | 0                     |
| statusList.Device_status                                  | 2               | 1                     |
| statusList.Display_Brightness_setting_status              | 255             | 255                   |
| statusList.Display_contrast_setting_status                | 3               | 3                     |
| statusList.Display_logotype_setting_status                | 2               | 2                     |
| statusList.Door_status                                    | 1               | 2                     |
| statusList.Energy_consumption_in_running_program          | 65535           | 65535                 |
| statusList.Energy_save_setting_status                     | 0               | 0                     |
| statusList.Error_F70                                      | 3               |                       |
| statusList.Error_F76                                      | 1               |                       |
| statusList.Error_f10                                      | 1               | 1                     |
| statusList.Error_f11                                      | 1               | 1                     |
| statusList.Error_f12                                      | 1               | 1                     |
| statusList.Error_f40                                      | 1               | 1                     |
| statusList.Error_f41                                      | 1               | 1                     |
| statusList.Error_f42                                      | 1               | 1                     |
| statusList.Error_f43                                      | 1               | 1                     |
| statusList.Error_f44                                      | 1               | 1                     |
| statusList.Error_f45                                      | 1               | 1                     |
| statusList.Error_f46                                      | 1               | 1                     |
| statusList.Error_f52                                      | 1               | 1                     |
| statusList.Error_f54                                      | 1               | 1                     |
| statusList.Error_f56                                      | 1               | 1                     |
| statusList.Error_f61                                      | 1               | 1                     |
| statusList.Error_f62                                      | 1               | 1                     |
| statusList.Error_f65                                      | 1               | 1                     |
| statusList.Error_f67                                      | 1               | 1                     |
| statusList.Error_f68                                      | 1               | 1                     |
| statusList.Error_f69                                      | 1               | 1                     |
| statusList.Error_f72                                      | 1               | 1                     |
| statusList.Error_f74                                      | 1               | 1                     |
| statusList.Error_f75                                      | 1               | 1                     |
| statusList.Error_read_out_1_code                          | 12              | 12                    |
| statusList.Error_read_out_1_cycle                         | 475             | 475                   |
| statusList.Error_read_out_1_status                        | 1               | 1                     |
| statusList.Error_read_out_2_code                          | 68              | 68                    |
| statusList.Error_read_out_2_cycle                         | 436             | 436                   |
| statusList.Error_read_out_2_status                        | 1               | 1                     |
| statusList.Error_read_out_3_code                          | 65              | 65                    |
| statusList.Error_read_out_3_cycle                         | 0               | 0                     |
| statusList.Error_read_out_3_status                        | 2               | 2                     |
| statusList.FOTA_status                                    | 1               | 1                     |
| statusList.Fan_sequence_setting_status                    | 2               | 2                     |
| statusList.Feedback_volumen_setting_status                | 3               | 3                     |
| statusList.Fill_salt                                      | 1               | 1                     |
| statusList.HardPairingStatus                              | 0               | 0                     |
| statusList.Heat_pump_setting_status                       | 0               | 0                     |
| statusList.High_temperature_status                        | 0               | 0                     |
| statusList.Interior_light_at_power_off_setting_status     | 2               | 2                     |
| statusList.Interior_light_status                          | 1               | 1                     |
| statusList.Language_status                                | 4               | 4                     |
| statusList.Last_run_program_id                            | 255             | 255                   |
| statusList.MDO_on_demand                                  | 0               |                       |
| statusList.MDO_on_demand_allowed                          | 0               |                       |
| statusList.Notification_volumen_setting_status            | 3               | 3                     |
| statusList.Odor_control_setting                           | 1               | 1                     |
| statusList.Pressure_calibration_setting_status            | 11              | 11                    |
| statusList.Remote_control_monitoring_set_commands         | 2               | 2                     |
| statusList.Remote_control_monitoring_set_commands_actions | 1               | 1                     |
| statusList.Rinse_aid_refill                               | 1               | 1                     |
| statusList.Rinse_aid_setting_status                       | 3               | 3                     |
| statusList.Sani_Lock                                      | 3               |                       |
| statusList.Sani_Lock_allowed                              | 3               |                       |
| statusList.Selected_program_Lower_wash_function           | 0               |                       |
| statusList.Selected_program_Upper_wash_function           | 0               |                       |
| statusList.Selected_program_auto_door_open_function       | 2               | 2                     |
| statusList.Selected_program_dry_function                  | 0               | 0                     |
| statusList.Selected_program_extra_drying_function         | 0               | 0                     |
| statusList.Selected_program_id_status                     | 1               | 1                     |
| statusList.Selected_program_mode                          | 2               | 2                     |
| statusList.Selected_program_storage_function              | 0               | 0                     |
| statusList.Selected_program_uv_function                   | 0               | 0                     |
| statusList.Session_pairing_active                         | 0               | 0                     |
| statusList.Session_pairing_confirmation                   | 0               | 0                     |
| statusList.Session_pairing_status                         | 0               | 0                     |
| statusList.Silence_on_demand                              | 0               |                       |
| statusList.Silence_on_demand_allowed                      | 0               |                       |
| statusList.Smart_Dry_function                             | 0               |                       |
| statusList.Soft_pairing_status                            | 0               | 0                     |
| statusList.Speed_on_demand                                | 1               |                       |
| statusList.Spend_on_demand_allowed                        | 3               |                       |
| statusList.Storage_mode_allowed                           | 1               |                       |
| statusList.Storage_mode_on_demand_stat                    | 0               |                       |
| statusList.Super_rinse_on_demand                          | 0               |                       |
| statusList.Super_rinse_on_demand_allowed                  | 0               |                       |
| statusList.Super_rinse_setting_status                     | 1               | 1                     |
| statusList.Super_rinse_status                             | 0               | 0                     |
| statusList.Tab_setting_status                             | 1               | 1                     |
| statusList.Temperature_unit_status                        | 1               | 1                     |
| statusList.Time_program_set_duration_status               | 0               | 0                     |
| statusList.Total_energy_consumption                       | 443             | 586                   |
| statusList.Total_number_of_cycles                         | 483             | 655                   |
| statusList.Total_run_time                                 | 1101            | 1481                  |
| statusList.Total_water_consumption                        | 5362            | 7253                  |
| statusList.UV_mode_on_demand                              | 2               |                       |
| statusList.UV_mode_on_demand_allowed                      | 3               |                       |
| statusList.Water_consumption_in_running_program           | 65535           | 65535                 |
| statusList.Water_hardness_setting_status                  | 1               | 1                     |
| statusList.Water_inlet_setting_status                     | 0               | 0                     |
| statusList.Water_save_setting_status                      | 0               | 0                     |
| statusList.Water_tank                                     | 0               | 0                     |
| statusList.daily_energy_kwh                               | 0               | 0                     |
| useTime                                                   | 1690885767539   | 1690885767539         |
| wifiId                                                    | <redacted>      | <redacted>            |

## Generated from

- [`015`](015-000.json)
- [`015`](015-dishwasher-60.2.json)
